==> knative-model-6.8.0-sources.jar: io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubBindingSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.knative.internal.pkg.tracker.Reference;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluent;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class GitHubBindingSpecFluent<A extends GitHubBindingSpecFluent<A>> extends BaseFluent<A>{
  public GitHubBindingSpecFluent() {
  }
  public GitHubBindingSpecFluent(GitHubBindingSpec instance) {
    instance = (instance != null ? instance : new GitHubBindingSpec());

    if (instance != null) {
      this.withAccessToken(instance.getAccessToken());
      this.withSubject(instance.getSubject());
      this.withAccessToken(instance.getAccessToken());
      this.withSubject(instance.getSubject());
    }
  }
  private SecretValueFromSourceBuilder accessToken;
  private ReferenceBuilder subject;
  public SecretValueFromSource buildAccessToken() {
    return this.accessToken!=null ?this.accessToken.build():null;
  }
  public A withAccessToken(SecretValueFromSource accessToken) {
    _visitables.get("accessToken").remove(this.accessToken);
    if (accessToken!=null){ this.accessToken= new SecretValueFromSourceBuilder(accessToken); _visitables.get("accessToken").add(this.accessToken);} else { this.accessToken = null; _visitables.get("accessToken").remove(this.accessToken); } return (A) this;
  }
  public boolean hasAccessToken() {
    return this.accessToken != null;
  }
  public AccessTokenNested<A> withNewAccessToken() {
    return new AccessTokenNested(null);
  }
  public AccessTokenNested<A> withNewAccessTokenLike(SecretValueFromSource item) {
    return new AccessTokenNested(item);
  }
  public AccessTokenNested<A> editAccessToken() {
    return withNewAccessTokenLike(java.util.Optional.ofNullable(buildAccessToken()).orElse(null));
  }
  public AccessTokenNested<A> editOrNewAccessToken() {
    return withNewAccessTokenLike(java.util.Optional.ofNullable(buildAccessToken()).orElse(new SecretValueFromSourceBuilder().build()));
  }
  public AccessTokenNested<A> editOrNewAccessTokenLike(SecretValueFromSource item) {
    return withNewAccessTokenLike(java.util.Optional.ofNullable(buildAccessToken()).orElse(item));
  }
  public Reference buildSubject() {
    return this.subject!=null ?this.subject.build():null;
  }
  public A withSubject(Reference subject) {
    _visitables.get("subject").remove(this.subject);
    if (subject!=null){ this.subject= new ReferenceBuilder(subject); _visitables.get("subject").add(this.subject);} else { this.subject = null; _visitables.get("subject").remove(this.subject); } return (A) this;
  }
  public boolean hasSubject() {
    return this.subject != null;
  }
  public SubjectNested<A> withNewSubject() {
    return new SubjectNested(null);
  }
  public SubjectNested<A> withNewSubjectLike(Reference item) {
    return new SubjectNested(item);
  }
  public SubjectNested<A> editSubject() {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(null));
  }
  public SubjectNested<A> editOrNewSubject() {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(new ReferenceBuilder().build()));
  }
  public SubjectNested<A> editOrNewSubjectLike(Reference item) {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitHubBindingSpecFluent that = (GitHubBindingSpecFluent) o;
    if (!java.util.Objects.equals(accessToken, that.accessToken)) return false;

    if (!java.util.Objects.equals(subject, that.subject)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(accessToken,  subject,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accessToken != null) { sb.append("accessToken:"); sb.append(accessToken + ","); }
    if (subject != null) { sb.append("subject:"); sb.append(subject); }
    sb.append("}");
    return sb.toString();
  }
  public class AccessTokenNested<N> extends SecretValueFromSourceFluent<AccessTokenNested<N>> implements Nested<N>{
    AccessTokenNested(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    SecretValueFromSourceBuilder builder;
    public N and() {
      return (N) GitHubBindingSpecFluent.this.withAccessToken(builder.build());
    }
    public N endAccessToken() {
      return and();
    }
    
  }
  public class SubjectNested<N> extends ReferenceFluent<SubjectNested<N>> implements Nested<N>{
    SubjectNested(Reference item) {
      this.builder = new ReferenceBuilder(this, item);
    }
    ReferenceBuilder builder;
    public N and() {
      return (N) GitHubBindingSpecFluent.this.withSubject(builder.build());
    }
    public N endSubject() {
      return and();
    }
    
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubBindingSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.knative.internal.pkg.tracker.Reference;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.tracker.ReferenceFluent;
import io.fabric8.knative.internal.pkg.tracker.ReferenceBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class GitHubBindingSpecFluent<A extends GitHubBindingSpecFluent<A>> extends BaseFluent<A>{
  public GitHubBindingSpecFluent() {
  }
  
  public GitHubBindingSpecFluent(GitHubBindingSpec instance) {
    this.copyInstance(instance);
  }
  private SecretValueFromSourceBuilder accessToken;
  private ReferenceBuilder subject;
  
  protected void copyInstance(GitHubBindingSpec instance) {
    instance = (instance != null ? instance : new GitHubBindingSpec());
  
    if (instance != null) {
        this.withAccessToken(instance.getAccessToken());
        this.withSubject(instance.getSubject());
        this.withAccessToken(instance.getAccessToken());
        this.withSubject(instance.getSubject());
      }
  }
  
  public SecretValueFromSource buildAccessToken() {
    return this.accessToken!=null ?this.accessToken.build():null;
  }
  
  public A withAccessToken(SecretValueFromSource accessToken) {
    _visitables.get("accessToken").remove(this.accessToken);
    if (accessToken!=null){ this.accessToken= new SecretValueFromSourceBuilder(accessToken); _visitables.get("accessToken").add(this.accessToken);} else { this.accessToken = null; _visitables.get("accessToken").remove(this.accessToken); } return (A) this;
  }
  
  public boolean hasAccessToken() {
    return this.accessToken != null;
  }
  
  public AccessTokenNested<A> withNewAccessToken() {
    return new AccessTokenNested(null);
  }
  
  public AccessTokenNested<A> withNewAccessTokenLike(SecretValueFromSource item) {
    return new AccessTokenNested(item);
  }
  
  public AccessTokenNested<A> editAccessToken() {
    return withNewAccessTokenLike(java.util.Optional.ofNullable(buildAccessToken()).orElse(null));
  }
  
  public AccessTokenNested<A> editOrNewAccessToken() {
    return withNewAccessTokenLike(java.util.Optional.ofNullable(buildAccessToken()).orElse(new SecretValueFromSourceBuilder().build()));
  }
  
  public AccessTokenNested<A> editOrNewAccessTokenLike(SecretValueFromSource item) {
    return withNewAccessTokenLike(java.util.Optional.ofNullable(buildAccessToken()).orElse(item));
  }
  
  public Reference buildSubject() {
    return this.subject!=null ?this.subject.build():null;
  }
  
  public A withSubject(Reference subject) {
    _visitables.get("subject").remove(this.subject);
    if (subject!=null){ this.subject= new ReferenceBuilder(subject); _visitables.get("subject").add(this.subject);} else { this.subject = null; _visitables.get("subject").remove(this.subject); } return (A) this;
  }
  
  public boolean hasSubject() {
    return this.subject != null;
  }
  
  public SubjectNested<A> withNewSubject() {
    return new SubjectNested(null);
  }
  
  public SubjectNested<A> withNewSubjectLike(Reference item) {
    return new SubjectNested(item);
  }
  
  public SubjectNested<A> editSubject() {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(null));
  }
  
  public SubjectNested<A> editOrNewSubject() {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(new ReferenceBuilder().build()));
  }
  
  public SubjectNested<A> editOrNewSubjectLike(Reference item) {
    return withNewSubjectLike(java.util.Optional.ofNullable(buildSubject()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    GitHubBindingSpecFluent that = (GitHubBindingSpecFluent) o;
    if (!java.util.Objects.equals(accessToken, that.accessToken)) return false;
  
    if (!java.util.Objects.equals(subject, that.subject)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(accessToken,  subject,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accessToken != null) { sb.append("accessToken:"); sb.append(accessToken + ","); }
    if (subject != null) { sb.append("subject:"); sb.append(subject); }
    sb.append("}");
    return sb.toString();
  }
  public class AccessTokenNested<N> extends SecretValueFromSourceFluent<AccessTokenNested<N>> implements Nested<N>{
    AccessTokenNested(SecretValueFromSource item) {
      this.builder = new SecretValueFromSourceBuilder(this, item);
    }
    SecretValueFromSourceBuilder builder;
    
    public N and() {
      return (N) GitHubBindingSpecFluent.this.withAccessToken(builder.build());
    }
    
    public N endAccessToken() {
      return and();
    }
    
  
  }
  public class SubjectNested<N> extends ReferenceFluent<SubjectNested<N>> implements Nested<N>{
    SubjectNested(Reference item) {
      this.builder = new ReferenceBuilder(this, item);
    }
    ReferenceBuilder builder;
    
    public N and() {
      return (N) GitHubBindingSpecFluent.this.withSubject(builder.build());
    }
    
    public N endSubject() {
      return and();
    }
    
  
  }

}
